@@ -3,16 +3,16 @@ if(.Platform$OS.type == "windows") {
 `import.from.Access` <-
 function(file=file.choose(), data.type="community", table=NULL, sitenames="sites", column="species", value="abundance", factor="", level="", cepnames=FALSE) {
     if (!require(RODBC)) {stop("Requires package RODBC")}
-    dataplace <- odbcConnectAccess(file)
+    dataplace <- RODBC::odbcConnectAccess(file)
     if (is.null(data.type) == TRUE) {data.type <- table}
     TYPES <- c("community", "environmental", "stacked")
     data.type <- match.arg(data.type, TYPES)
     if (is.null(table) == TRUE) {table <- data.type}
     if (data.type == "stacked") {
-        stackeddata <- sqlFetch(dataplace, table)  
+        stackeddata <- RODBC::sqlFetch(dataplace, table)  
         result <- makecommunitydataset(stackeddata, row=sitenames, column=column, value=value, factor=factor, level=level)
     }else{
-         result <- sqlFetch(dataplace, table, rownames=sitenames)
+         result <- RODBC::sqlFetch(dataplace, table, rownames=sitenames)
     }
     close(dataplace)
     rownames(result) <- make.names(rownames(result), unique=T)
@@ -27,16 +27,16 @@ function(file=file.choose(), data.type="community", table=NULL, sitenames="sites
 `import.from.Access2007` <-
 function(file=file.choose(), data.type="community", table=NULL, sitenames="sites", column="species", value="abundance", factor="", level="", cepnames=FALSE) {
     if (!require(RODBC)) {stop("Requires package RODBC")}
-    dataplace <- odbcConnectAccess2007(file)
+    dataplace <- RODBC::odbcConnectAccess2007(file)
     if (is.null(data.type) == TRUE) {data.type <- table}
     TYPES <- c("community", "environmental", "stacked")
     data.type <- match.arg(data.type, TYPES)
     if (is.null(table) == TRUE) {table <- data.type}
     if (data.type == "stacked") {
-        stackeddata <- sqlFetch(dataplace, table)  
+        stackeddata <- RODBC::sqlFetch(dataplace, table)  
         result <- makecommunitydataset(stackeddata, row=sitenames, column=column, value=value, factor=factor, level=level)
     }else{
-         result <- sqlFetch(dataplace, table, rownames=sitenames)
+         result <- RODBC::sqlFetch(dataplace, table, rownames=sitenames)
     }
     close(dataplace)
     rownames(result) <- make.names(rownames(result), unique=T)
